from setuptools import setup, find_packages
setup(name="MSDSF22M016_pkg",
version="0.0.1",
description= "A Simple Library",
Long_description="this is a library in which you can calculate speed, distance and time, find greater or smaller number, calculate addition, subtraction, addition, multiolication,you can check whether a number is Palindrome or not,you can find unique elements of list,you can find divisor of number",
author="Shumaila Zahid",
packages=['MSDSF22M016_pkg'],
install_requires = [])